@@ -1,13 +1,13 @@
 package Workflow::Config::XML;
 
-# $Id: XML.pm 361 2008-04-05 13:23:31Z jonasbn $
+# $Id: XML.pm,v 1.1 2004/09/13 02:03:09 cwinters Exp $
 
 use strict;
 use base qw( Workflow::Config );
 use Log::Log4perl       qw( get_logger );
 use Workflow::Exception qw( configuration_error );
 
-$Workflow::Config::XML::VERSION = '1.05';
+$Workflow::Config::XML::VERSION  = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -29,7 +29,7 @@ my %XML_OPTIONS = (
         KeyAttr    => [],
     },
     workflow => {
-        ForceArray => [ 'extra_data', 'state', 'action',  'resulting_state', 'condition', 'observer' ],
+        ForceArray => [ 'extra_data', 'state', 'action', 'condition' ],
         KeyAttr    => [],
     },
 );
@@ -49,23 +49,13 @@ sub parse {
         my $file_name = ( ref $item ) ? '[scalar ref]' : $item;
         $log->is_info &&
             $log->info( "Will parse '$type' XML config file '$file_name'" );
-        my $this_config;
-        eval{
-            $this_config = $self->_translate_xml( $type, $item );
-        };
-        # If processing multiple config files, this makes it much easier
-        # to find a problem.
-        die "Processing $file_name: $@" if $@;
+        my $this_config = $self->_translate_xml( $type, $item );
         $log->is_info &&
             $log->info( "Parsed XML '$file_name' ok" );
-
-	# This sets the outer-most tag to use
-	# when returning the parsed XML.
-	my $outer_tag = $self->get_config_type_tag($type);
-        if ( ref $this_config->{ $outer_tag } eq 'ARRAY' ) {
+        if ( ref $this_config->{ $type } eq 'ARRAY' ) {
             $log->is_debug &&
                 $log->debug( "Adding multiple configurations for '$type'" );
-            push @config, @{ $this_config->{ $outer_tag } };
+            push @config, @{ $this_config->{ $type } };
         }
         else {
             $log->is_debug &&
@@ -116,16 +106,6 @@ Implementation of configuration parser for XML files/data; requires
 L<XML::Simple> to be installed. See L<Workflow::Config> for C<parse()>
 description.
 
-=head2 METHODS
-
-=head3 parse ( $type, @items )
-
-This method parses the configuration provided it is in XML format.
-
-Takes two parameters: a $type indication and an array of of items
-
-Returns a list of config parameters as a array upon success.
-
 =head1 SEE ALSO
 
 L<XML::Simple>
